import pyproj
"""
Denne filen inneholder konstanter og beskrivelse av geosfæriske objekter.
For eksempel, diverse ellipsoider brukt av forskjellige GNSS
"""


class GNSS(dict):
    # geod - ellipsoid, definert vha pyproj
    # geod.a - semi-major axis, m
    # geod.f - flattrykning
    # omega_e - Jordens rotasjonshastighet, rad/s
    # GM - jordsentrisk gravitasjonskonstanten, m3/s2
    pass


GPS = GNSS()
GPS.geod = pyproj.Geod(ellps="WGS84")
GPS.GM = 3.986005e14
GPS.omega_e = 7.2921151467e-5

GAL = GNSS()
GAL.geod = pyproj.Geod(ellps="WGS84")
GAL.GM = 3.986004418e14
GAL.omega_e = 7.2921151467e-5

BDS = GNSS()
BDS.geod = pyproj.Geod(ellps="GRS80")
BDS.GM = 3.986004418e14
BDS.omega_e = 7.2921150e-5

GLO = GNSS()
GLO.geod = pyproj.Geod(ellps="PZ90")
GLO.GM = 3.986004418e14
GLO.omega_e = 7.2921150e-5

c = 299792458  # lyshastighet, [m/s]

ecef = pyproj.Proj(proj='geocent', ellps='WGS84', datum='WGS84')
lla = pyproj.Proj(proj='latlong', ellps='WGS84', datum='WGS84')
utm = pyproj.Proj(proj='utm', ellps='WGS84', datum='WGS84', zone=32)


def sv_to_gnss(sv: str) -> GNSS:
    """
    Hjelperfunksjon for å finne ut riktig GNSS parametre for en gitt SV
    :param sv: str. satellittnavn, e.g. G01
    :return: korrekt GNSS objekt
    """
    if sv[0] == 'G':
        return GPS
    elif sv[0] == 'E':
        return GAL
    elif sv[0] == 'C':
        return BDS
    elif sv[0] == 'R':
        return GLO
    else:
        raise ValueError("Unsupported GNSS: %s" % sv[0])